/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.web.ui.tag.breadcrumbtrail.pathdiscovery;

import com.topcoder.web.ui.tag.breadcrumbtrail.BreadCrumbException;
import com.topcoder.web.ui.tag.breadcrumbtrail.BreadCrumbNode;
import com.topcoder.web.ui.tag.breadcrumbtrail.PathDiscovery;

import javax.servlet.jsp.PageContext;


/**
 * <p>This implementation of the PathDiscovery will attempt to create a static site map and then
 *  apply dynamic information to that site map. The dynamic information can either be in matching
 *   nodes with different query strings or in new nodes that will be assumed to map to the last
 *    known node.</p>
 * <p>Thread Safety: Implementations of this interface should be thread safe</p>
 *
 *
 *
 * @author Pops, TCSDEVELOPER
 * @version 2.0
 */
public class DynamicPathDiscovery implements PathDiscovery {
    /**
     * <p>This static constant represents the session scope attribute name that will contain
     *  the current known path. This constant will be used by this class to retrieve the current
     *   path. The current path will be of NodePair[] type representing the know path from the
     *   root (0th index) to the prior page (lenght-1th index) .</p>
     */
    public static final String CURRENT_PATH = DynamicPathDiscovery.class.getName() + ".currentPath";

    /**
     * <p>This static constant represents the session scope attribute name that will contain the
     *  site map.
     * This constant will be used by this class to retrieve the site map.  The site map will be
     *  a Map with
     * NodeMatcher as the key and a List of NodeMatcher as the value and can be empty.  This map
     * represents the NodeMatcher parent to it's children NodeMatcher(s) if any.  The list can
     *  be empty
     * if there are no children of the parent (ie a leaf node)</p>
     */
    public static final String CURRENT_SITEMAP = DynamicPathDiscovery.class.getName() + ".siteMap";

    /**
     * <p>Constructs the DynamicPathDiscovery object.</p>
     */
    public DynamicPathDiscovery() {
    }

    /**
     * <p>This method attempts to determine the page from the current node to the root and return
     *  that path.</p>
     *
     *
     * @param currentNode A non-null current node
     * @param pageContext A non-null page context
     * @return A null if the path can't be found or a non-empty array representing the path
     *  from root node (0th index) to current node (size-1th index)
     * @throws IllegalArgumentException if either arg is null
     * @throws BreadCrumbException if an exception occurred while processing
     */
    public BreadCrumbNode[] getPath(BreadCrumbNode currentNode, PageContext pageContext)
        throws BreadCrumbException {
        if (currentNode == null) {
            throw new IllegalArgumentException("currentNode cannot be null.");
        }

        if (pageContext == null) {
            throw new IllegalArgumentException("pageContext cannot be null.");
        }

        return null;
    }
}
